@@ -6,7 +6,6 @@ try:
 except ModuleNotFoundError:
     raise ModuleNotFoundError("Jupyter Server must be installed to use this extension.")
 
-from jupyter_server.utils import url_path_join
 from traitlets import Float, Int, Type
 from ypy_websocket.ystore import BaseYStore  # type: ignore
 
@@ -47,7 +46,7 @@ class YDocExtension(ExtensionApp):
         config=True,
         help="""The YStore class to use for storing Y updates. Defaults to JupyterSQLiteYStore,
         which stores Y updates in a '.jupyter_ystore.db' SQLite database in the current
-        directory.""",
+        directory, and clears history every 24 hours.""",
     )
 
     def initialize_settings(self):
@@ -63,9 +62,7 @@ class YDocExtension(ExtensionApp):
     def initialize_handlers(self):
         self.handlers.extend(
             [
-                url_path_join(
-                    self.settings["base_url"], (r"/api/yjs/roomid/(.*)", YDocRoomIdHandler)
-                ),
-                url_path_join(self.settings["base_url"], (r"/api/yjs/(.*)", YDocWebSocketHandler)),
+                (r"/api/yjs/roomid/(.*)", YDocRoomIdHandler),
+                (r"/api/yjs/(.*)", YDocWebSocketHandler),
             ]
         )
